Discount Party Supplies - Free Shipping: Contact Us
Description: My Paper Shop contact us page is a great way to get your questions answered with ease. Thanks for contacting us today.

# Contact Us

Help Quicklinks: Return Policy | FAQs | See all help topics...

We're Here To Help
Your satisfaction is important to us! Use the form below to email us your questions about products, online orders, store experiences and more.

Order Questions:
If you need help or have any other questions concerning your order, please email us or call: 888-412-7467.

Office Address: (Orders ship from Wisconsin or Illinois)
My Paper Shop.Com, Inc.
1224 East Katella Avenue, STE 209
Orange, CA 92867 US
Phone: 888-412-7467
Fax: 714-509-0068

Contact Us: 888-412-7467 (Se Habla Espanol)

Our products are not sold in case smaller quantities. We do not offer printed product catalogs.

You must javascript enabled to use this form.

* Bold fields are required.

* Email Address:
* Confirm Email Address:
* First Name:
* Last Name:
Yes, please send me valuable discount coupons for future purchases
Company/Organization:
* Address:
Apt, Suite, Bldg#:
* City:
* State:
Other State/Province:
* Zip Code:
* Country:
* Daytime Phone:
Fax:

Please select a topic that best describes your comment or question:

Please let us know how you heard about us?

Order Number (if applicable):
* Comments or Questions:

Copyright © 2000 - 2016 My Paper Shop.Com, Inc. All Rights Reserved.

*MARKER* 0